.. default-role:: py:obj

.. include:: ../README.rst

.. include:: ../CONTRIBUTING.rst

.. default-role::

API Documentation
=================

Loudspeaker Arrays
------------------

.. automodule:: sfs.array
   :members:
   :undoc-members:
   :exclude-members: ArrayData

Tapering
--------

.. automodule:: sfs.tapering
   :members:
   :undoc-members:

Monochromatic Sources
---------------------

.. automodule:: sfs.mono.source
   :members:
   :undoc-members:

Monochromatic Driving Functions
-------------------------------

.. automodule:: sfs.mono.drivingfunction
   :members:
   :undoc-members:

Monochromatic Sound Fields
--------------------------

.. automodule:: sfs.mono.synthesized
   :members:
   :undoc-members:

Plotting
--------

.. automodule:: sfs.plot
   :members:
   :undoc-members:

Utilities
---------

.. automodule:: sfs.util
   :members:
   :undoc-members:

.. only:: html

   Index
   -----
 
   :ref:`genindex`

Version History
---------------

.. default-role:: py:obj

.. include:: ../NEWS.rst

.. default-role::
